@@ -15,9 +15,9 @@ def shorthelp():
 	print "   "+turquoise("emerge")+" < "+turquoise("--sync")+" | "+turquoise("--metadata")+" | "+turquoise("--info")+" >"
 	print "   "+turquoise("emerge")+" "+turquoise("--resume")+" [ "+green("--pretend")+" | "+green("--ask")+" | "+green("--skipfirst")+" ]"
 	print "   "+turquoise("emerge")+" "+turquoise("--help")+" [ "+green("system")+" | "+green("config")+" | "+green("sync")+" ] "
-	print bold("Options:")+" "+green("-")+"["+green("abcCdDefhikKlnoOpPsSuUvV")+"] ["+green("--oneshot")+"] ["+green("--newuse")+"] ["+green("--noconfmem")+"]"
+	print bold("Options:")+" "+green("-")+"["+green("abcCdDefhikKlnNoOpPsSuUvV")+"] ["+green("--oneshot")+"] ["+green("--newuse")+"] ["+green("--noconfmem")+"]"
 	print      "                                    ["+green("--columns")+"] ["+green("--nospinner")+"]"
-	print bold("Actions:")+" [ "+green("--clean")+" | "+green("--depclean")+" | "+green("--inject")+" | "+green("--prune")+" | "+green("--regen")+" | "+green("--search")+" | "+green("--unmerge")+" ]"
+	print bold("Actions:")+" [ "+green("--clean")+" | "+green("--depclean")+" | "+green("--prune")+" | "+green("--regen")+" | "+green("--search")+" | "+green("--unmerge")+" ]"
 	print
 
 def help(myaction,myopts,havecolor=1):
@@ -113,6 +113,11 @@ def help(myaction,myopts,havecolor=1):
 		print "              your system. Specify arguments using the dependency specification"
 		print "              format described in the "+bold("--clean")+" action above."
 		print
+		print "       "+green("--config")
+		print "              Run package specific actions needed to  be  executed  after  the"
+		print "              emerge  process  has completed.  This usually entails configuration"
+		print "              file setup or other similar setups that the user  may  wish to run."
+		print
 		print turquoise("Options:")
 		print "       "+green("--ask")+" ("+green("-a")+" short option)"
 		print "              before performing the merge, display what ebuilds and tbz2s will"
@@ -185,7 +190,7 @@ def help(myaction,myopts,havecolor=1):
 		print "              downloaded from the remote server without consulting packages"
 		print "              existing in the packages directory."
 		print
-		print "       "+green("--newuse")
+		print "       "+green("--newuse")+" ("+green("-N")+" short option)"
 		print "              Tells emerge to include installed packages where USE flags have "
 		print "              changed since installation."
 		print
@@ -334,7 +339,7 @@ and the KDE configuration dirs; more may be added in the future.
 
 When Portage installs a file into a protected directory tree like /etc, any
 existing files will not be overwritten.  If a file of the same name already
-exists, Portage will change the name of the to-be- installed file from 'foo' to
+exists, Portage will change the name of the to-be-installed file from 'foo' to
 '._cfg0000_foo'.  If '._cfg0000_foo' already exists, this name becomes
 '._cfg0001_foo', etc.  In this way, existing files are not overwritten,
 allowing the administrator to manually merge the new config files and avoid any
